Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/owncloud/client.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorHannah von Reth <hannah.vonreth@owncloud.com>2021-12-06 16:43:35 +0300
committerHannah von Reth <vonreth@kde.org>2021-12-09 12:37:51 +0300
commit1d8333344c120b79da9b0ad1a1a878b4ac448ea1 (patch)
treee4b82fc4fd16612cd362d62ae4f21a8453050bc2 /src/common
parentc94b9170af37bc2cfa41dffc6a1777f31e9efc13 (diff)
Fix parameter name
Diffstat (limited to 'src/common')
-rw-r--r--src/common/vfs.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/common/vfs.h b/src/common/vfs.h
index 12680c329..d2c768e8f 100644
--- a/src/common/vfs.h
+++ b/src/common/vfs.h
@@ -197,20 +197,20 @@ public:
* Usually this would forward to setting the pin state flag in the db table,
* but some vfs plugins will store the pin state in file attributes instead.
*
* folderPath is relative to the sync folder. Can be "" for root folder.
*/
- virtual OC_REQUIRED_RESULT bool setPinState(const QString &folderPath, PinState state) = 0;
+ virtual OC_REQUIRED_RESULT bool setPinState(const QString &relFilePath, PinState state) = 0;
/** Returns the pin state of an item at a path.
*
* Usually backed by the db's effectivePinState() function but some vfs
* plugins will override it to retrieve the state from elsewhere.
*
* folderPath is relative to the sync folder. Can be "" for root folder.
*
* Returns none on retrieval error.
*/
- virtual OC_REQUIRED_RESULT Optional<PinState> pinState(const QString &folderPath) = 0;
+ virtual OC_REQUIRED_RESULT Optional<PinState> pinState(const QString &relFilePath) = 0;
/** Returns availability status of an item at a path.
*
@@ -197,20 +197,20 @@ public:
* but some vfs plugins will store the pin state in file attributes instead.
*
- * folderPath is relative to the sync folder. Can be "" for root folder.
+ * relFilePath is relative to the sync folder. Can be "" for root folder.
*/
@@ -197,20 +197,20 @@ public:
* plugins will override it to retrieve the state from elsewhere.
*
- * folderPath is relative to the sync folder. Can be "" for root folder.
+ * relFilePath is relative to the sync folder. Can be "" for root folder.
*
* Returns none on retrieval error.